@@ -2,11 +2,15 @@ from .choose import choose, choose_one
 from .iterators import infinite_counter, take_n, is_instance, skip_first, zip_shifted, \
     stop_after, iter_dict_of_list, shift, other_sequence_no_longer_than, count, even, \
     odd, n_th, smart_enumerate, smart_zip, unique, ConstruableIterator, walk, length, map_list, \
-    is_empty
-from .sequences import is_last, add_next, half_cartesian, group_quantity, Multirun
+    is_empty, IteratorListAdapter, enumerate2, to_iterator
+from .sequences import is_last, add_next, half_cartesian, group_quantity, Multirun, make_list, \
+    infinite_iterator
+from .average import RollingArithmeticAverage
 
 __all__ = ['choose', 'choose_one', 'infinite_counter', 'take_n', 'is_instance', 'is_last',
            'add_next', 'ConstruableIterator', 'walk', 'length', 'smart_zip',
            'half_cartesian', 'skip_first', 'zip_shifted', 'stop_after', 'group_quantity',
            'iter_dict_of_list', 'shift', 'other_sequence_no_longer_than', 'count', 'n_th',
-           'even', 'odd', 'Multirun', 'smart_enumerate', 'unique', 'map_list', 'is_empty']
+           'even', 'odd', 'Multirun', 'smart_enumerate', 'unique', 'map_list', 'is_empty',
+           'make_list', 'RollingArithmeticAverage',
+           'IteratorListAdapter', 'enumerate2', 'infinite_iterator', 'to_iterator']
