@@ -4,7 +4,7 @@ import typing as tp
 import warnings
 
 from ..recast_exceptions import rethrow_as, silence_excs
-from ..decorators import for_argument
+from ..decorators import for_argument, wraps
 
 T, U = tp.TypeVar('T'), tp.TypeVar('U')
 IteratorOrIterable = tp.Union[tp.Iterator[T], tp.Iterable[T]]
@@ -358,6 +358,58 @@ def n_th(iterator: IteratorOrIterable, n: int = 0) -> T:
         raise IndexError('Iterable was too short')
 
 
+class IteratorListAdapter:
+    """
+    A wrapper around an iterator that enables it to be processed as a list.
+
+    Ie. the generator will now support __contains__, __len__ and __getitem__.
+    If a call to such a method is done, the generator will be unfolded in memory so this
+    might take a ton of memory! You've been warned!
+
+    :param iterator:
+    """
+    __slots__ = ('unfolded', 'iterator', 'list', 'pointer')
+
+    def __init__(self, iterator: tp.Iterator):
+        self.iterator = iter(iterator)
+        self.list = None        # type: list
+        self.unfolded = False
+        self.pointer = 0
+
+    def __iter__(self):
+        if self.unfolded:
+            return iter(self.list)
+        else:
+            return self
+
+    @rethrow_as(IndexError, StopIteration)
+    def __next__(self):
+        if self.unfolded:
+            self.pointer += 1
+            return self.list[self.pointer-1]    # throws: IndexError
+        else:
+            return next(self.iterator)
+
+    def __unfold(self):
+        if self.unfolded:
+            return
+        self.list = list(self.iterator)
+        self.unfolded = True
+        self.pointer = 0
+
+    def __getitem__(self, item):
+        self.__unfold()
+        return self.list[item]
+
+    def __contains__(self, item) -> bool:
+        self.__unfold()
+        return item in self.list
+
+    def __len__(self) -> int:
+        self.__unfold()
+        return len(self.list)
+
+
 def is_empty(iterable: IteratorOrIterable) -> bool:
     """
     Checks whether an iterator is empty.
@@ -385,6 +437,30 @@ def map_list(fun: tp.Callable, iterable: IteratorOrIterable) -> tp.List:
     return list(map(fun, iterable))
 
 
+def to_iterator(fun):
+    """
+    Convert function to an iterator. You can replace the following code:
+
+    >>> def iterator(x):
+    >>>     for y in x:
+    >>>         yield fun(y)
+
+    with
+
+    >>> @to_iterator
+    >>> def fun(y):
+    >>>     ...
+
+    and now call fun instead of iterator. fun will accept a single argument - the iterable,
+    and assume that the function you decorate also takes a single argument - the item
+    """
+    @wraps(fun)
+    def inner(iterable):
+        for item in iterable:
+            yield fun(item)
+    return inner
+
+
 def smart_zip(*iterators: IteratorOrIterable) -> tp.Iterator[tp.Tuple[T, ...]]:
     """
     Zip in such a way that resulted tuples are automatically expanded.
@@ -410,6 +486,21 @@ def smart_zip(*iterators: IteratorOrIterable) -> tp.Iterator[tp.Tuple[T, ...]]:
         yield tuple(a)
 
 
+def enumerate2(iterable: IteratorOrIterable, start: int = 0,
+               step: int = 1) -> tp.Iterator[tp.Tuple[int, T]]:
+    """
+    Enumerate with a custom step
+
+    :param iterable: iterable to enumerate
+    :param start: value to start at
+    :param step: step to add during each iteration
+    """
+    v = start
+    for item in iterable:
+        yield v, item
+        v += step
+
+
 def smart_enumerate(iterator: IteratorOrIterable, start: int = 0,
                     step: int = 1) -> tp.Iterator[tp.Tuple]:
     """
